<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Sluiten (%1) </translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Inklappen</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Uitklappen</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Waarschuwing verwerpen</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln woord</numerusform>
            <numerusform>%Ln woorden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuut</numerusform>
            <numerusform>%Ln minuten</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% van %Ln minuut</numerusform>
            <numerusform>%L1% van %Ln minuten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% van %Ln woord</numerusform>
            <numerusform>%L1% van %Ln woorden</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Dagelijkse voortgang</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Langste serie</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Huidige serie</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/B</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dag</numerusform>
            <numerusform>%n dagen</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% van uw dagelijkse doel</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Taal instellen</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Naamloos %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (alleen-lezen)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>‘%1’ kan niet worden opgeslagen.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Opslaan als</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>‘%1’ kan niet worden overschreven.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Bestandsnaam wijzigen</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>De bestandsnaam van ‘%1’ kan niet worden gewijzigd.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Bestand herladen?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Wilt u ‘%1’ herladen van de schijf?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Alle niet-opgeslagen wijzigingen gaan verloren.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Herladen</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Naamloos %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Door op te slaan als platte tekst wordt alle opmaak verwijderd. Weet u het zeker?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Bestand is gewijzigd</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>‘%1’ is gewijzigd door een ander programma.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Wilt u het bestand herladen?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Herladen</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Negeren</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Bestand is verwijderd</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>‘%1’ is verwijderd door een ander programma.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Wilt u het bestand opslaan of sluiten?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Het archief kan niet worden geopend.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Zoeken naar:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Vervangen door:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Kleine en hoofdletters negeren</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Alleen hele woorden</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Reguliere uitdrukkingen</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Richting begin zoeken</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Richting einde zoeken</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Zoeken</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>Ve&amp;rvangen</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>&amp;Alles vervangen</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Vervangen</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>%n vondst vervangen?</numerusform>
            <numerusform>%n vondsten vervangen?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>De zoekterm is niet gevonden.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument-tekst</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich text-formaat</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Platte tekst</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Alle ondersteunde bestanden</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument platte XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Spelling controleren…</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(geen suggesties gevonden)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Afbeelding openen</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Kies de programmataal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Let op</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart FocusWriter om de taalwijziging toe te passen.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Het archief kan niet worden geopend.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistieken</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Werkbalk</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Spellingcontrole</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Kies een woordenboek</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Het archief kan niet worden geopend.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Dit archief bevat geen bruikbare woordenlijst.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Sneltoetsen</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Eén of meerdere sneltoetsen botsen. Wilt u tóch doorgaan?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>‘%1’ bestaat al. Wilt u het vervangen?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Dagelijks doel</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Niets</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Aantal minuten:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Aantal woorden:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Bewerking</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Altijd verticaal centreren</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Blokcursor</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Afgevlakte letters</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Typemachinegeluiden</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Slimme aanhalingstekens:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dubbel</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Enkel</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scènes</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Scheiding:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Cursorpositie onthouden</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Woordtelling</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Paginatelling</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Paragraaftelling</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Tekentelling</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Aantal tekens:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Aantal paragrafen:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Woordtelling-algoritme</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Wilt u de dagelijkse voortgang voor vandaag op nul zetten?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Bytevolgorde-markering toevoegen aan plattetekstbestanden</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Standaardformaat:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Vandaag op nul zetten</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Geschiedenis</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Geschiedenis onthouden</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Series tonen</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minimale voortgang voor series:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Woordgrenzen bepalen</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Tekentelling door zes delen</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Elke letter als één woord tellen</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Paginatelling-algoritme</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stijl</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Alleen pictogrammen</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Alleen tekst</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Tekst naast pictogrammen</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Tekst onder pictogrammen</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Tekstpositie:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Acties</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Naar boven schuiven</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Naar onder schuiven</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Scheidingsteken toevoegen</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Opdracht</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Sneltoets</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Actie</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Spelling controleren tijdens typen</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Woorden in HOOFDLETTERS negeren</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Woorden met getallen negeren</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Persoonlijk woordenboek</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Huidige map verwijderen?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Vormgeving</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Schuifbalk altijd tonen</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Bovenste balk altijd tonen</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Onderbalk altijd tonen</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Niet-ondersteund rtf-bestand.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Onverwachts het einde van het bestand bereikt.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+pijltje omlaag</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Scènes omhoog verplaatsen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+pijltje omhoog</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Scènelijst tonen/verbergen</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Scènelijst (%1) tonen</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Scènelijst (%1) verbergen</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filteren</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Scènes omlaag verplaatsen</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Scènelijst vergroten/verkleinen</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Sessies beheren</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;essies</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Klonen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Overschakelen naar</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nieuwe sessie</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Sessie klonen</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Sessienaam wijzigen</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Sessie verwijderen?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Sessienaam:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Deze sessienaam is al in gebruik.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nieuw…</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Crtl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Beheren…</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+B</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Standaardwaarden herstellen</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Sneltoets:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Bezig met vervangen van aanhalingstekens…</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Even geduld…</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Spellingcontrole</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Toevoegen</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Negeren</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Alles ne&amp;geren</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Wijzigen</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Alles w&amp;ijzigen</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Niet in woordenboek:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Vervangen door:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Bezig met controleren van spelling…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Even geduld…</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Wilt u doorgaan met controleren vanaf het begin van het bestand?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>De spellingcontrole is afgerond.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Symbolen</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Onlangs gebruikte symbolen</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Alle symbolen</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Invoegen</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blokken</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Naamloos %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Geen afbeelding</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Tegels</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Gecentreerd</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Uitgerekt</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Geschaald</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Gezoomd</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Doorzichtigheid:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Positie:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breedte:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Hoeken van tekstachtergrond afronden</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Straal:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Tekstachtergrond vervagen</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Schaduw van tekstachtergrond</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Verticale verschuiving:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Randen</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Venster:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Pagina:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Eerste regel inspringen</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Boven:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Onder:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Thema bewerken</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Vensterachtergrond</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Kleur:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Afbeelding:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> pixels</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Tekstachtergrond</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Lettertype:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Spelfout:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Regelafstand</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Enkel</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>Anderhalve regel</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Twee regels</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proportioneel</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Hoogte:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Paragraafuitlijning</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Tabbreedte:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nieuw thema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Thema&apos;s</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Rustig blauw</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Ouderwets</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Ruimtereis</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Schrijftafel</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Klonen</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Aangepast</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importeren</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Wilt u ‘%1’ verwijderen?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Thema&apos;s (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Thema importeren</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Thema exporteren</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Grimmig weer</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Betovering</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Spionagespel</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Kalmte</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Wilt u de tijdklok verwijderen?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Aantal woorden:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Aantal pagina&apos;s:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Aantal paragrafen:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Aantal tekens:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Wachttijd instellen</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Tijd instellen</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Wachttijd:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tijd:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Wekker</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Soort:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memo:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Geen lopende tijdklokken</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Tijdklokken</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Recent</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Tijdklokbewerking afbreken?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Bezig met laden van thema&apos;s…</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Bezig met laden van geluiden…</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Naamloos</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Bestand openen</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Over FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Een eenvoudige, schermvullende tekstverwerker</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onder de  &lt;a href=%1&gt;GPL 3&lt;/a&gt;-licentie</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Maakt gebruik van pictogrammen uit het &lt;a href=%1&gt;Oxygen&lt;/a&gt;-pictogramthema</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Gebruikt onder de &lt;a href=%1&gt;LGPL 3&lt;/a&gt; -licentie</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Aantal tekens: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Aantal pagina&apos;s: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Aantal paragrafen: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Aantal woorden: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Bezig met openen van %1…</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Naamloos %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Alle documenten tonen</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Ga naar volgend document</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Ga naar vorig document</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Ga naar eerste document</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Ga naar laatste document</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Ga naar document %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Bezig met laden van instellingen…</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>De noodopslag is niet beschrijfbaar.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter is niet goed afgesloten.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Wilt u de veiligheidskopie herstellen?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Enkele bestanden kunnen niet worden geopend.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Enkele bestanden zijn geopend in de alleen-lezenmodus.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>‘%1’ is nieuwer dan de opgeslagen kopie.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Wilt u het nieuwere bestand overschrijven?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Wijzigingen opslaan?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Wilt u de wijzigingen aan ‘%1’ opslaan alvorens af te sluiten?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Als u de wijzigingen niet opslaat, dan gaan ze verloren.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>De typemachinegeluiden kunnen niet worden geladen.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Openen…</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Her&amp;laden</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Op&amp;slaan</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Opslaan &amp;als…</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>Naam &amp;wijzigen…</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>A&amp;lles opslaan</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Sessies beheren</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nieuwe sessie</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>A&amp;fdrukken…</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Sl&amp;uiten</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Af&amp;sluiten</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>B&amp;ewerken</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Ongedaan maken</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Opnieuw</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>K&amp;nippen</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>K&amp;opiëren</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Pl&amp;akken</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Plakken &amp;zonder opmaak</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;Alles selecteren</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>&amp;Scène selecteren</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>O&amp;pmaak</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Vetgedrukt</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Cursief</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Onderstrepen</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Doorhalen</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Sup&amp;erscript</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Su&amp;bscript</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>&amp;Links uitlijnen</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>&amp;Centreren</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>&amp;Rechts uitlijnen</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Uitvu&amp;llen</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Inspringing verkleinen</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>I&amp;nspringing vergroten</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Van li&amp;nks naar rechts</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Van &amp;rechts naar links</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Hulpmiddelen</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Zoeken…</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Vooru&amp;it zoeken</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>&amp;Achteruit zoeken</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>Ve&amp;rvangen…</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Slimme aanhalingstekens</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>&amp;Document bijwerken</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Selecti&amp;e bijwerken</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Spelling&amp;controle…</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Taa&amp;l instellen…</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Tijdklokken…</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ymbolen…</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Dagelijkse voortgang</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>In&amp;stellingen</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Werkbalk &amp;tonen</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Pictogrammen tonen in &amp;menu</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Gef&amp;ocuste tekst</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Beeld&amp;vullend</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Mi&amp;nimaliseren</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Thema&apos;s…</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Instellingen…</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Focus uitgeschakeld</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Focussen op één regel</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Focussen op drie regels</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Paragraaf</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Focussen op paragraaf</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programmataa&amp;l…</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Enkele bestanden worden niet ondersteund en kunnen niet worden geopend.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Uit</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Eén rege&amp;l</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Drie regels</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Pa&amp;gina-instellingen…</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Kop</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Kop &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Kop &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Kop &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Kop &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Kop &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Kop &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normaal</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Slimme aanhalingstekens bijwerken</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Slimme aanhalingstekens bijwerken</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>De in de huidige sessie te openen bestanden.</translation>
    </message>
</context>
</TS>
